<?php

namespace Notifications\Notification\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Notifications\Notification\Http\Requests\NotificationsRequest;
use Notifications\Notification\Models\Notifications;

/**
 * Admin web controller class.
 */
class NotificationsWorkflowController extends BaseController
{

    /**
     * Workflow controller function for notifications.
     *
     * @param Model   $notifications
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(NotificationsRequest $request, Notifications $notifications, $step)
    {

        try {

            $notifications->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('notification::notifications.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/notifications/notifications/' . $notifications->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/notifications/notifications/' . $notifications->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for notifications.
     *
     * @param Model   $notifications
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Notifications $notifications, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $notifications->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('notification::notifications.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('notification::admin.notifications.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('notification::admin.notifications.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('notification::admin.notifications.message', $data)->render();

        }

    }
}
