<?php

namespace Notifications\Notification\Policies;

use Litepie\User\Contracts\UserPolicy;
use Notifications\Notification\Models\Notifications;

class NotificationsPolicy
{

    /**
     * Determine if the given user can view the notifications.
     *
     * @param UserPolicy $user
     * @param Notifications $notifications
     *
     * @return bool
     */
    public function view(UserPolicy $user, Notifications $notifications)
    {
        if ($user->canDo('notification.notifications.view') && $user->isAdmin()) {
            return true;
        }

        return $notifications->user_id == user_id() && $notifications->user_type == user_type();
    }

    /**
     * Determine if the given user can create a notifications.
     *
     * @param UserPolicy $user
     * @param Notifications $notifications
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('notification.notifications.create');
    }

    /**
     * Determine if the given user can update the given notifications.
     *
     * @param UserPolicy $user
     * @param Notifications $notifications
     *
     * @return bool
     */
    public function update(UserPolicy $user, Notifications $notifications)
    {
        if ($user->canDo('notification.notifications.edit') && $user->isAdmin()) {
            return true;
        }

        return $notifications->user_id == user_id() && $notifications->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given notifications.
     *
     * @param UserPolicy $user
     * @param Notifications $notifications
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Notifications $notifications)
    {
        return $notifications->user_id == user_id() && $notifications->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given notifications.
     *
     * @param UserPolicy $user
     * @param Notifications $notifications
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Notifications $notifications)
    {
        if ($user->canDo('notification.notifications.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given notifications.
     *
     * @param UserPolicy $user
     * @param Notifications $notifications
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Notifications $notifications)
    {
        if ($user->canDo('notification.notifications.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
